# rball
![CI](https://github.com/grburgess/rball/workflows/CI/badge.svg?branch=master)
[![codecov](https://codecov.io/gh/grburgess/rball/branch/master/graph/badge.svg)](https://codecov.io/gh/grburgess/rball)
[![Docs](https://github.com/grburgess/rball/actions/workflows/docs.yml/badge.svg)](https://jmichaelburgess.com/rball/)

![PyPI](https://img.shields.io/pypi/v/rball)
![PyPI - Downloads](https://img.shields.io/pypi/dm/rball)

![alt text](https://raw.githubusercontent.com/grburgess/rball/master/docs/media/logo.png)


A generic spherical grid interpolator for dispersion based instrument responses


* Free software: GNU General Public License v3
* Documentation: jmichaelburgess.com/rball



## Credits

